======
byword
======

CLI for generating synonyms using `Datamuse API <https://www.datamuse.com/api/>`_.

Usage
=====

::

    $ byword hello
    hi
    howdy
    hullo
    how-do-you-do
    goodbye
    goodnight
    greeting
    ciao
    bonjour
    hola

Installing
==========

::

    pipx install byword

